diff --git a/dh_autoreconf b/dh_autoreconf
index f863aa2..679064e 100755
--- a/dh_autoreconf
+++ b/dh_autoreconf
@@ -83,8 +83,28 @@ shall not be run:
     export AUTOMAKE = automake1.10
     export LIBTOOLIZE = true
 
+=head1 BEHAVIOR IF NO COMMAND IS GIVEN
+
+If no command is given to dh_autoreconf, it will run the following commands
+in order:
+
+    autoreconf -f -i
+    gtkdocize  --copy         # if GTK_DOC_CHECK is called in configure.{ac,in}
+
+If you have directories listed in debian/autoreconf, autoreconf will be run
+on all of them, whereas gtkdocize may be run only on the top-level build
+directory.
 =cut
 
+# Read a file, return an array of lines.
+sub readfile ($) {
+    my $file = shift;
+    open(DAT, $file) || error("Could not read file: " . $file);
+    my @data=<DAT>;
+    close(DAT);
+    return @data;
+}
+
 init(options => { "mode=s" => \$dh{MODE},
                   "as-needed" => \$dh{AS_NEEDED}});
 
@@ -123,6 +143,16 @@ my $find = $modes{$dh{MODE} || "md5"} ||
 
 complex_doit("$find > debian/autoreconf.before");
 
+
+# Run gtkdocize automatically
+if (-f "/usr/bin/gtkdocize" and not @ARGV) {
+    my $configure = (-e "configure.ac") ? "configure.ac" : "configure.in";
+
+    if (-e $configure && grep(/^GTK_DOC_CHECK/, readfile($configure))) {
+        doit("gtkdocize", "--copy");
+    }
+}
+
 # Run autoreconf to recreate the needed files.
 @ARGV ? doit(@ARGV, @{$dh{U_PARAMS}}) : doit('autoreconf', '-f', '-i', @directories);
 
